Function framels::parse_dir

source ·
pub fn parse_dir(input_path: &str) -> Paths
parse_dir

List files and directories in the targeted directory, take a String as input and return a Vec<String> of the entries.