Function framels::basic_listing
source · pub fn basic_listing(frames: Paths, multithreaded: bool) -> PathsPackedExpand description
basic_listing
Description
This function is the main function of the library it use a list of
filename as in input and pack the frame sequences using a new filename
like toto.***.jpg@158-179
It take a Vec<String> of entries as an input
- Pack the frames
- Return a Vector of path packed
Example
Example of output
./samples/small/aaa.***.tif@1-5
./samples/small/foo_bar.ex
Example of output with non exr file
./samples/small/foo.exr@None
Example as a library
use framels::{basic_listing, parse_dir, paths::{Paths,Join}};
fn main() {
// Perform directory listing
let in_paths: Paths = parse_dir("./samples/small");
// Generate results based on arguments
let results: String = basic_listing(in_paths, false).get_paths().join("\n");
println!("{}", results)
}